@@ -631,6 +631,7 @@ class TibberHome:
                 accumulatedProduction
                 accumulatedConsumption
                 accumulatedCost
+                accumulatedReward
                 currency
                 minPower
                 averagePower
@@ -646,6 +647,8 @@ class TibberHome:
                 signalStrength
                 accumulatedConsumptionLastHour
                 accumulatedProductionLastHour
+                powerFactor
+                powerReactive
             }
            }
         """
